@@ -1,7 +1,8 @@
 '''
 # aws-iot-s3 module
 
-<!--BEGIN STABILITY BANNER-->
+<!--BEGIN STABILITY BANNER-->---
+
 
 ![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
 
@@ -9,6 +10,7 @@
 > future version. These are not subject to the [Semantic Versioning](https://semver.org/) model.
 > This means that while you may use them, you may need to update your source code when upgrading to a newer version of this package.
 
+---
 <!--END STABILITY BANNER-->
 
 | **Reference Documentation**:| <span style="font-weight: normal">https://docs.aws.amazon.com/solutions/latest/constructs/</span>|
@@ -22,78 +24,38 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-iot-s3`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.iots3`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS IoT MQTT topic rule and an Amazon S3 Bucket pattern.
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { IotToS3Props, IotToS3 } from '@aws-solutions-constructs/aws-iot-s3';
+const { IotToS3Props, IotToS3 } from '@aws-solutions-constructs/aws-iot-s3';
 
-const constructProps: IotToS3Props = {
-  iotTopicRuleProps: {
-    topicRulePayload: {
-      ruleDisabled: false,
-      description: "Testing the IotToS3 Pattern",
-      sql: "SELECT * FROM 'solutions/constructs'",
-      actions: []
+const props: IotToS3Props = {
+    iotTopicRuleProps: {
+        topicRulePayload: {
+            ruleDisabled: false,
+            description: "Testing the IotToS3 Pattern",
+            sql: "SELECT * FROM 'solutions/constructs'",
+            actions: []
+        }
     }
-  }
 };
 
-new IotToS3(this, 'test-iot-s3-integration', constructProps);
+new IotToS3(this, 'test-iot-s3-integration', props);
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_iot_s3 import IotToS3Props, IotToS3
-from aws_cdk import (
-    aws_iot as iot,
-    Stack
-)
-from constructs import Construct
-
-
-IotToS3(self, 'test_iot_s3',
-        iot_topic_rule_props=iot.CfnTopicRuleProps(
-            topic_rule_payload=iot.CfnTopicRule.TopicRulePayloadProperty(
-                rule_disabled=False,
-                description="Testing the IotToS3 Pattern",
-                sql="SELECT * FROM 'solutions/constructs'",
-                actions=[]
-            )
-        ))
+```text
+new IotToS3(scope: Construct, id: string, props: IotToS3Props);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-import java.util.List;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.iot.*;
-import software.amazon.awscdk.services.iot.CfnTopicRule.TopicRulePayloadProperty;
-import software.amazon.awsconstructs.services.iots3.*;
-
-new IotToS3(this, "test_iot_s3", new IotToS3Props.Builder()
-        .iotTopicRuleProps(new CfnTopicRuleProps.Builder()
-                .topicRulePayload(new TopicRulePayloadProperty.Builder()
-                        .ruleDisabled(false)
-                        .description("Testing the IotToS3 Pattern")
-                        .sql("SELECT * FROM 'solutions/constructs'")
-                        .actions(List.of())
-                        .build())
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`IotToS3Props`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -145,7 +107,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -157,30 +119,28 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_iam
 import aws_cdk.aws_iot
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class IotToS3(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-s3.IotToS3",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         s3_key: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -197,22 +157,6 @@ class IotToS3(
         :access: public
         :summary: Constructs a new instance of the IotToSqs class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                s3_key: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToS3Props(
             iot_topic_rule_props=iot_topic_rule_props,
             bucket_props=bucket_props,
@@ -224,27 +168,27 @@ class IotToS3(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotActionsRole")
     def iot_actions_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "iotActionsRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
         return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -266,10 +210,10 @@ class IotToS3Props:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         s3_key: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -289,24 +233,6 @@ class IotToS3Props:
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(logging_bucket_props, dict):
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
-        if __debug__:
-            def stub(
-                *,
-                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                s3_key: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
-            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
-            check_type(argname="argument existing_bucket_interface", value=existing_bucket_interface, expected_type=type_hints["existing_bucket_interface"])
-            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
-            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
-            check_type(argname="argument s3_key", value=s3_key, expected_type=type_hints["s3_key"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
